# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ContainerV1Acl',
    'ContainerV1AclRead',
    'ContainerV1Consumer',
    'ContainerV1SecretRef',
    'OrderV1Meta',
    'SecretV1Acl',
    'SecretV1AclRead',
    'GetContainerAclResult',
    'GetContainerAclReadResult',
    'GetContainerConsumerResult',
    'GetContainerSecretRefResult',
    'GetSecretAclResult',
    'GetSecretAclReadResult',
]

@pulumi.output_type
class ContainerV1Acl(dict):
    def __init__(__self__, *,
                 read: Optional['outputs.ContainerV1AclRead'] = None):
        if read is not None:
            pulumi.set(__self__, "read", read)

    @property
    @pulumi.getter
    def read(self) -> Optional['outputs.ContainerV1AclRead']:
        return pulumi.get(self, "read")


@pulumi.output_type
class ContainerV1AclRead(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "createdAt":
            suggest = "created_at"
        elif key == "projectAccess":
            suggest = "project_access"
        elif key == "updatedAt":
            suggest = "updated_at"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ContainerV1AclRead. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ContainerV1AclRead.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ContainerV1AclRead.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 created_at: Optional[builtins.str] = None,
                 project_access: Optional[builtins.bool] = None,
                 updated_at: Optional[builtins.str] = None,
                 users: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.str created_at: The date the container was created.
        :param builtins.bool project_access: Whether the container is accessible project wide.
               Defaults to `true`.
        :param builtins.str updated_at: The date the container was last updated.
        :param Sequence[builtins.str] users: The list of user IDs, which are allowed to access the
               container, when `project_access` is set to `false`.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if project_access is not None:
            pulumi.set(__self__, "project_access", project_access)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[builtins.str]:
        """
        The date the container was created.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="projectAccess")
    def project_access(self) -> Optional[builtins.bool]:
        """
        Whether the container is accessible project wide.
        Defaults to `true`.
        """
        return pulumi.get(self, "project_access")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[builtins.str]:
        """
        The date the container was last updated.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def users(self) -> Optional[Sequence[builtins.str]]:
        """
        The list of user IDs, which are allowed to access the
        container, when `project_access` is set to `false`.
        """
        return pulumi.get(self, "users")


@pulumi.output_type
class ContainerV1Consumer(dict):
    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 url: Optional[builtins.str] = None):
        """
        :param builtins.str name: Human-readable name for the Container. Does not have
               to be unique.
        :param builtins.str url: The consumer URL.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        Human-readable name for the Container. Does not have
        to be unique.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def url(self) -> Optional[builtins.str]:
        """
        The consumer URL.
        """
        return pulumi.get(self, "url")


@pulumi.output_type
class ContainerV1SecretRef(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "secretRef":
            suggest = "secret_ref"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ContainerV1SecretRef. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ContainerV1SecretRef.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ContainerV1SecretRef.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 secret_ref: builtins.str,
                 name: Optional[builtins.str] = None):
        """
        :param builtins.str secret_ref: The secret reference / where to find the secret, URL.
        :param builtins.str name: The name of the secret reference. The reference names must correspond the container type, more details are available [here](https://docs.openstack.org/barbican/stein/api/reference/containers.html).
        """
        pulumi.set(__self__, "secret_ref", secret_ref)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="secretRef")
    def secret_ref(self) -> builtins.str:
        """
        The secret reference / where to find the secret, URL.
        """
        return pulumi.get(self, "secret_ref")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        The name of the secret reference. The reference names must correspond the container type, more details are available [here](https://docs.openstack.org/barbican/stein/api/reference/containers.html).
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class OrderV1Meta(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bitLength":
            suggest = "bit_length"
        elif key == "payloadContentType":
            suggest = "payload_content_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OrderV1Meta. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OrderV1Meta.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OrderV1Meta.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 algorithm: builtins.str,
                 bit_length: builtins.int,
                 expiration: Optional[builtins.str] = None,
                 mode: Optional[builtins.str] = None,
                 name: Optional[builtins.str] = None,
                 payload_content_type: Optional[builtins.str] = None):
        """
        :param builtins.str algorithm: Algorithm to use for key generation.
        :param builtins.int bit_length: Bit lenght of key to be generated.
        :param builtins.str expiration: This is a UTC timestamp in ISO 8601 format YYYY-MM-DDTHH:MM:SSZ. If set, the secret will not be available after this time.
        :param builtins.str mode: The mode to use for key generation.
        :param builtins.str name: The name of the secret set by the user.
        :param builtins.str payload_content_type: The media type for the content of the secrets payload. Must be one of `text/plain`, `text/plain;charset=utf-8`, `text/plain; charset=utf-8`, `application/octet-stream`, `application/pkcs8`.
        """
        pulumi.set(__self__, "algorithm", algorithm)
        pulumi.set(__self__, "bit_length", bit_length)
        if expiration is not None:
            pulumi.set(__self__, "expiration", expiration)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if payload_content_type is not None:
            pulumi.set(__self__, "payload_content_type", payload_content_type)

    @property
    @pulumi.getter
    def algorithm(self) -> builtins.str:
        """
        Algorithm to use for key generation.
        """
        return pulumi.get(self, "algorithm")

    @property
    @pulumi.getter(name="bitLength")
    def bit_length(self) -> builtins.int:
        """
        Bit lenght of key to be generated.
        """
        return pulumi.get(self, "bit_length")

    @property
    @pulumi.getter
    def expiration(self) -> Optional[builtins.str]:
        """
        This is a UTC timestamp in ISO 8601 format YYYY-MM-DDTHH:MM:SSZ. If set, the secret will not be available after this time.
        """
        return pulumi.get(self, "expiration")

    @property
    @pulumi.getter
    def mode(self) -> Optional[builtins.str]:
        """
        The mode to use for key generation.
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        The name of the secret set by the user.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="payloadContentType")
    def payload_content_type(self) -> Optional[builtins.str]:
        """
        The media type for the content of the secrets payload. Must be one of `text/plain`, `text/plain;charset=utf-8`, `text/plain; charset=utf-8`, `application/octet-stream`, `application/pkcs8`.
        """
        return pulumi.get(self, "payload_content_type")


@pulumi.output_type
class SecretV1Acl(dict):
    def __init__(__self__, *,
                 read: Optional['outputs.SecretV1AclRead'] = None):
        if read is not None:
            pulumi.set(__self__, "read", read)

    @property
    @pulumi.getter
    def read(self) -> Optional['outputs.SecretV1AclRead']:
        return pulumi.get(self, "read")


@pulumi.output_type
class SecretV1AclRead(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "createdAt":
            suggest = "created_at"
        elif key == "projectAccess":
            suggest = "project_access"
        elif key == "updatedAt":
            suggest = "updated_at"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SecretV1AclRead. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SecretV1AclRead.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SecretV1AclRead.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 created_at: Optional[builtins.str] = None,
                 project_access: Optional[builtins.bool] = None,
                 updated_at: Optional[builtins.str] = None,
                 users: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.str created_at: The date the secret was created.
        :param builtins.bool project_access: Whether the secret is accessible project wide.
               Defaults to `true`.
        :param builtins.str updated_at: The date the secret was last updated.
        :param Sequence[builtins.str] users: The list of user IDs, which are allowed to access the
               secret, when `project_access` is set to `false`.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if project_access is not None:
            pulumi.set(__self__, "project_access", project_access)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[builtins.str]:
        """
        The date the secret was created.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="projectAccess")
    def project_access(self) -> Optional[builtins.bool]:
        """
        Whether the secret is accessible project wide.
        Defaults to `true`.
        """
        return pulumi.get(self, "project_access")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[builtins.str]:
        """
        The date the secret was last updated.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def users(self) -> Optional[Sequence[builtins.str]]:
        """
        The list of user IDs, which are allowed to access the
        secret, when `project_access` is set to `false`.
        """
        return pulumi.get(self, "users")


@pulumi.output_type
class GetContainerAclResult(dict):
    def __init__(__self__, *,
                 read: 'outputs.GetContainerAclReadResult'):
        pulumi.set(__self__, "read", read)

    @property
    @pulumi.getter
    def read(self) -> 'outputs.GetContainerAclReadResult':
        return pulumi.get(self, "read")


@pulumi.output_type
class GetContainerAclReadResult(dict):
    def __init__(__self__, *,
                 created_at: builtins.str,
                 updated_at: builtins.str,
                 project_access: Optional[builtins.bool] = None,
                 users: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.str created_at: The date the container ACL was created.
        :param builtins.str updated_at: The date the container ACL was last updated.
        :param builtins.bool project_access: Whether the container is accessible project wide.
        :param Sequence[builtins.str] users: The list of user IDs, which are allowed to access the container,
               when `project_access` is set to `false`.
        """
        pulumi.set(__self__, "created_at", created_at)
        pulumi.set(__self__, "updated_at", updated_at)
        if project_access is not None:
            pulumi.set(__self__, "project_access", project_access)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        The date the container ACL was created.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        The date the container ACL was last updated.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="projectAccess")
    def project_access(self) -> Optional[builtins.bool]:
        """
        Whether the container is accessible project wide.
        """
        return pulumi.get(self, "project_access")

    @property
    @pulumi.getter
    def users(self) -> Optional[Sequence[builtins.str]]:
        """
        The list of user IDs, which are allowed to access the container,
        when `project_access` is set to `false`.
        """
        return pulumi.get(self, "users")


@pulumi.output_type
class GetContainerConsumerResult(dict):
    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 url: Optional[builtins.str] = None):
        """
        :param builtins.str name: The Container name.
        :param builtins.str url: The consumer URL.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        The Container name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def url(self) -> Optional[builtins.str]:
        """
        The consumer URL.
        """
        return pulumi.get(self, "url")


@pulumi.output_type
class GetContainerSecretRefResult(dict):
    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 secret_ref: Optional[builtins.str] = None):
        """
        :param builtins.str name: The Container name.
        :param builtins.str secret_ref: The secret reference / where to find the secret, URL.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secret_ref is not None:
            pulumi.set(__self__, "secret_ref", secret_ref)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        The Container name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="secretRef")
    def secret_ref(self) -> Optional[builtins.str]:
        """
        The secret reference / where to find the secret, URL.
        """
        return pulumi.get(self, "secret_ref")


@pulumi.output_type
class GetSecretAclResult(dict):
    def __init__(__self__, *,
                 read: 'outputs.GetSecretAclReadResult'):
        pulumi.set(__self__, "read", read)

    @property
    @pulumi.getter
    def read(self) -> 'outputs.GetSecretAclReadResult':
        return pulumi.get(self, "read")


@pulumi.output_type
class GetSecretAclReadResult(dict):
    def __init__(__self__, *,
                 created_at: builtins.str,
                 updated_at: builtins.str,
                 project_access: Optional[builtins.bool] = None,
                 users: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.str created_at: The date the secret ACL was created.
        :param builtins.str updated_at: The date the secret ACL was last updated.
        :param builtins.bool project_access: Whether the secret is accessible project wide.
        :param Sequence[builtins.str] users: The list of user IDs, which are allowed to access the secret, when
               `project_access` is set to `false`.
        """
        pulumi.set(__self__, "created_at", created_at)
        pulumi.set(__self__, "updated_at", updated_at)
        if project_access is not None:
            pulumi.set(__self__, "project_access", project_access)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        The date the secret ACL was created.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        The date the secret ACL was last updated.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="projectAccess")
    def project_access(self) -> Optional[builtins.bool]:
        """
        Whether the secret is accessible project wide.
        """
        return pulumi.get(self, "project_access")

    @property
    @pulumi.getter
    def users(self) -> Optional[Sequence[builtins.str]]:
        """
        The list of user IDs, which are allowed to access the secret, when
        `project_access` is set to `false`.
        """
        return pulumi.get(self, "users")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['QuotaV2Args', 'QuotaV2']

@pulumi.input_type
class QuotaV2Args:
    def __init__(__self__, *,
                 project_id: pulumi.Input[builtins.str],
                 api_export_size: Optional[pulumi.Input[builtins.int]] = None,
                 recordset_records: Optional[pulumi.Input[builtins.int]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 zone_records: Optional[pulumi.Input[builtins.int]] = None,
                 zone_recordsets: Optional[pulumi.Input[builtins.int]] = None,
                 zones: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a QuotaV2 resource.
        :param pulumi.Input[builtins.str] project_id: ID of the project to manage quota. Changing this
               creates new quota.
        :param pulumi.Input[builtins.int] api_export_size: The maximum number of zones that can be
               exported via the API.
        :param pulumi.Input[builtins.int] recordset_records: The maximum number of records in a
               recordset.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 DNS client. If
               omitted, the `region` argument of the provider is used. Changing this creates
               a new DNS quota.
        :param pulumi.Input[builtins.int] zone_records: The maximum number of records in a zone.
        :param pulumi.Input[builtins.int] zone_recordsets: The maximum number of recordsets in a zone.
        :param pulumi.Input[builtins.int] zones: The maximum number of zones that can be created.
        """
        pulumi.set(__self__, "project_id", project_id)
        if api_export_size is not None:
            pulumi.set(__self__, "api_export_size", api_export_size)
        if recordset_records is not None:
            pulumi.set(__self__, "recordset_records", recordset_records)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if zone_records is not None:
            pulumi.set(__self__, "zone_records", zone_records)
        if zone_recordsets is not None:
            pulumi.set(__self__, "zone_recordsets", zone_recordsets)
        if zones is not None:
            pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[builtins.str]:
        """
        ID of the project to manage quota. Changing this
        creates new quota.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="apiExportSize")
    def api_export_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of zones that can be
        exported via the API.
        """
        return pulumi.get(self, "api_export_size")

    @api_export_size.setter
    def api_export_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "api_export_size", value)

    @property
    @pulumi.getter(name="recordsetRecords")
    def recordset_records(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of records in a
        recordset.
        """
        return pulumi.get(self, "recordset_records")

    @recordset_records.setter
    def recordset_records(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "recordset_records", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region in which to obtain the V2 DNS client. If
        omitted, the `region` argument of the provider is used. Changing this creates
        a new DNS quota.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="zoneRecords")
    def zone_records(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of records in a zone.
        """
        return pulumi.get(self, "zone_records")

    @zone_records.setter
    def zone_records(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "zone_records", value)

    @property
    @pulumi.getter(name="zoneRecordsets")
    def zone_recordsets(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of recordsets in a zone.
        """
        return pulumi.get(self, "zone_recordsets")

    @zone_recordsets.setter
    def zone_recordsets(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "zone_recordsets", value)

    @property
    @pulumi.getter
    def zones(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of zones that can be created.
        """
        return pulumi.get(self, "zones")

    @zones.setter
    def zones(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "zones", value)


@pulumi.input_type
class _QuotaV2State:
    def __init__(__self__, *,
                 api_export_size: Optional[pulumi.Input[builtins.int]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 recordset_records: Optional[pulumi.Input[builtins.int]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 zone_records: Optional[pulumi.Input[builtins.int]] = None,
                 zone_recordsets: Optional[pulumi.Input[builtins.int]] = None,
                 zones: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering QuotaV2 resources.
        :param pulumi.Input[builtins.int] api_export_size: The maximum number of zones that can be
               exported via the API.
        :param pulumi.Input[builtins.str] project_id: ID of the project to manage quota. Changing this
               creates new quota.
        :param pulumi.Input[builtins.int] recordset_records: The maximum number of records in a
               recordset.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 DNS client. If
               omitted, the `region` argument of the provider is used. Changing this creates
               a new DNS quota.
        :param pulumi.Input[builtins.int] zone_records: The maximum number of records in a zone.
        :param pulumi.Input[builtins.int] zone_recordsets: The maximum number of recordsets in a zone.
        :param pulumi.Input[builtins.int] zones: The maximum number of zones that can be created.
        """
        if api_export_size is not None:
            pulumi.set(__self__, "api_export_size", api_export_size)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if recordset_records is not None:
            pulumi.set(__self__, "recordset_records", recordset_records)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if zone_records is not None:
            pulumi.set(__self__, "zone_records", zone_records)
        if zone_recordsets is not None:
            pulumi.set(__self__, "zone_recordsets", zone_recordsets)
        if zones is not None:
            pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter(name="apiExportSize")
    def api_export_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of zones that can be
        exported via the API.
        """
        return pulumi.get(self, "api_export_size")

    @api_export_size.setter
    def api_export_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "api_export_size", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of the project to manage quota. Changing this
        creates new quota.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="recordsetRecords")
    def recordset_records(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of records in a
        recordset.
        """
        return pulumi.get(self, "recordset_records")

    @recordset_records.setter
    def recordset_records(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "recordset_records", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region in which to obtain the V2 DNS client. If
        omitted, the `region` argument of the provider is used. Changing this creates
        a new DNS quota.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="zoneRecords")
    def zone_records(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of records in a zone.
        """
        return pulumi.get(self, "zone_records")

    @zone_records.setter
    def zone_records(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "zone_records", value)

    @property
    @pulumi.getter(name="zoneRecordsets")
    def zone_recordsets(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of recordsets in a zone.
        """
        return pulumi.get(self, "zone_recordsets")

    @zone_recordsets.setter
    def zone_recordsets(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "zone_recordsets", value)

    @property
    @pulumi.getter
    def zones(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of zones that can be created.
        """
        return pulumi.get(self, "zones")

    @zones.setter
    def zones(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "zones", value)


@pulumi.type_token("openstack:dns/quotaV2:QuotaV2")
class QuotaV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_export_size: Optional[pulumi.Input[builtins.int]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 recordset_records: Optional[pulumi.Input[builtins.int]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 zone_records: Optional[pulumi.Input[builtins.int]] = None,
                 zone_recordsets: Optional[pulumi.Input[builtins.int]] = None,
                 zones: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Manages DNS quota in OpenStack DNS Service.

        > **Note:** This usually requires admin privileges.

        > **Note:** This resource has a no-op deletion so no actual actions will be
        done against the OpenStack API in case of delete call.

        ## Import

        Quotas can be imported using the `project_id/region_name`, e.g.

        ```sh
        $ pulumi import openstack:dns/quotaV2:QuotaV2 quota_1 2a0f2240-c5e6-41de-896d-e80d97428d6b/region_1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] api_export_size: The maximum number of zones that can be
               exported via the API.
        :param pulumi.Input[builtins.str] project_id: ID of the project to manage quota. Changing this
               creates new quota.
        :param pulumi.Input[builtins.int] recordset_records: The maximum number of records in a
               recordset.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 DNS client. If
               omitted, the `region` argument of the provider is used. Changing this creates
               a new DNS quota.
        :param pulumi.Input[builtins.int] zone_records: The maximum number of records in a zone.
        :param pulumi.Input[builtins.int] zone_recordsets: The maximum number of recordsets in a zone.
        :param pulumi.Input[builtins.int] zones: The maximum number of zones that can be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QuotaV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages DNS quota in OpenStack DNS Service.

        > **Note:** This usually requires admin privileges.

        > **Note:** This resource has a no-op deletion so no actual actions will be
        done against the OpenStack API in case of delete call.

        ## Import

        Quotas can be imported using the `project_id/region_name`, e.g.

        ```sh
        $ pulumi import openstack:dns/quotaV2:QuotaV2 quota_1 2a0f2240-c5e6-41de-896d-e80d97428d6b/region_1
        ```

        :param str resource_name: The name of the resource.
        :param QuotaV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QuotaV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_export_size: Optional[pulumi.Input[builtins.int]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 recordset_records: Optional[pulumi.Input[builtins.int]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 zone_records: Optional[pulumi.Input[builtins.int]] = None,
                 zone_recordsets: Optional[pulumi.Input[builtins.int]] = None,
                 zones: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QuotaV2Args.__new__(QuotaV2Args)

            __props__.__dict__["api_export_size"] = api_export_size
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["recordset_records"] = recordset_records
            __props__.__dict__["region"] = region
            __props__.__dict__["zone_records"] = zone_records
            __props__.__dict__["zone_recordsets"] = zone_recordsets
            __props__.__dict__["zones"] = zones
        super(QuotaV2, __self__).__init__(
            'openstack:dns/quotaV2:QuotaV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_export_size: Optional[pulumi.Input[builtins.int]] = None,
            project_id: Optional[pulumi.Input[builtins.str]] = None,
            recordset_records: Optional[pulumi.Input[builtins.int]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            zone_records: Optional[pulumi.Input[builtins.int]] = None,
            zone_recordsets: Optional[pulumi.Input[builtins.int]] = None,
            zones: Optional[pulumi.Input[builtins.int]] = None) -> 'QuotaV2':
        """
        Get an existing QuotaV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] api_export_size: The maximum number of zones that can be
               exported via the API.
        :param pulumi.Input[builtins.str] project_id: ID of the project to manage quota. Changing this
               creates new quota.
        :param pulumi.Input[builtins.int] recordset_records: The maximum number of records in a
               recordset.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 DNS client. If
               omitted, the `region` argument of the provider is used. Changing this creates
               a new DNS quota.
        :param pulumi.Input[builtins.int] zone_records: The maximum number of records in a zone.
        :param pulumi.Input[builtins.int] zone_recordsets: The maximum number of recordsets in a zone.
        :param pulumi.Input[builtins.int] zones: The maximum number of zones that can be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QuotaV2State.__new__(_QuotaV2State)

        __props__.__dict__["api_export_size"] = api_export_size
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["recordset_records"] = recordset_records
        __props__.__dict__["region"] = region
        __props__.__dict__["zone_records"] = zone_records
        __props__.__dict__["zone_recordsets"] = zone_recordsets
        __props__.__dict__["zones"] = zones
        return QuotaV2(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="apiExportSize")
    def api_export_size(self) -> pulumi.Output[builtins.int]:
        """
        The maximum number of zones that can be
        exported via the API.
        """
        return pulumi.get(self, "api_export_size")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[builtins.str]:
        """
        ID of the project to manage quota. Changing this
        creates new quota.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="recordsetRecords")
    def recordset_records(self) -> pulumi.Output[builtins.int]:
        """
        The maximum number of records in a
        recordset.
        """
        return pulumi.get(self, "recordset_records")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        The region in which to obtain the V2 DNS client. If
        omitted, the `region` argument of the provider is used. Changing this creates
        a new DNS quota.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="zoneRecords")
    def zone_records(self) -> pulumi.Output[builtins.int]:
        """
        The maximum number of records in a zone.
        """
        return pulumi.get(self, "zone_records")

    @property
    @pulumi.getter(name="zoneRecordsets")
    def zone_recordsets(self) -> pulumi.Output[builtins.int]:
        """
        The maximum number of recordsets in a zone.
        """
        return pulumi.get(self, "zone_recordsets")

    @property
    @pulumi.getter
    def zones(self) -> pulumi.Output[builtins.int]:
        """
        The maximum number of zones that can be created.
        """
        return pulumi.get(self, "zones")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'StackV1StackOutput',
]

@pulumi.output_type
class StackV1StackOutput(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "outputKey":
            suggest = "output_key"
        elif key == "outputValue":
            suggest = "output_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StackV1StackOutput. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StackV1StackOutput.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StackV1StackOutput.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 output_key: builtins.str,
                 output_value: builtins.str,
                 description: Optional[builtins.str] = None):
        """
        :param builtins.str description: The description of the stack resource.
        """
        pulumi.set(__self__, "output_key", output_key)
        pulumi.set(__self__, "output_value", output_value)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="outputKey")
    def output_key(self) -> builtins.str:
        return pulumi.get(self, "output_key")

    @property
    @pulumi.getter(name="outputValue")
    def output_value(self) -> builtins.str:
        return pulumi.get(self, "output_value")

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        The description of the stack resource.
        """
        return pulumi.get(self, "description")


